@@ -327,7 +327,7 @@ fn issue_450() {
 <h1>It works!</h1>
 \`\`\`
 `);"#,
-        r#"console.log(`\n\`\`\`html\n<h1>It works!</h1>\n\`\`\`\n`);"#,
+        "console.log(`\n\\`\\`\\`html\n<h1>It works!</h1>\n\\`\\`\\`\n`);",
     );
 }
 
